@@ -1,9 +1,11 @@
 from fa_purity.cmd.core import (
     Cmd,
+    CmdUnwrapper,
     unsafe_unwrap,
 )
 
 __all__ = [
     "Cmd",
+    "CmdUnwrapper",
     "unsafe_unwrap",
 ]
