@@ -41,6 +41,9 @@ class FrozenDict(Mapping[_K, _V], _FrozenDict[_K, _V]):
     def __repr__(self) -> str:
         return f"{self.__class__.__name__}{self._dict}"
 
+    def __hash__(self) -> int:
+        return hash(frozenset(self._dict.items()))
+
 
 def chain(unchained: FrozenList[FrozenList[_T]]) -> FrozenList[_T]:
     return tuple(item for items in unchained for item in items)
