@@ -36,6 +36,7 @@ from fa_purity.result.core import (
     ResultE,
 )
 from fa_purity.result.factory import (
+    ResultFactory,
     try_get,
 )
 from fa_purity.result.transform import (
@@ -79,11 +80,15 @@ class Unfolder:
         return _to_primitive(self.value, prim_type)
 
     def to_any_primitive(self) -> ResultE[Primitive]:
-        if is_primitive(self.value):
-            return Result.success(self.value)
-        return Result.failure(
+        factory: ResultFactory[Primitive, Exception] = ResultFactory()
+        fail = factory.failure(
             invalid_type.new("to_any_primitive", "Primitive", self.value)
         )
+        return self.jval.map(
+            factory.success,
+            lambda _: fail,
+            lambda _: fail,
+        )
 
     def to_none(self) -> Result[None, InvalidType]:
         if self.value is None:
@@ -91,11 +96,17 @@ class Unfolder:
         return Result.failure(invalid_type.new("to_none", "None", self.value))
 
     def to_list(self) -> UnfoldResult[FrozenList[JsonValue]]:
-        if isinstance(self.value, tuple):
-            return Result.success(self.value)
-        return Result.failure(
+        factory: ResultFactory[
+            FrozenList[JsonValue], InvalidType
+        ] = ResultFactory()
+        fail = factory.failure(
             invalid_type.new("to_list", "FrozenList[JsonValue]", self.value)
         )
+        return self.jval.map(
+            lambda _: fail,
+            factory.success,
+            lambda _: fail,
+        )
 
     def to_optional(
         self, transform: Callable[[Unfolder], UnfoldResult[_T]]
@@ -127,13 +138,19 @@ class Unfolder:
         return self.to_list().map(lambda l: tuple(Unfolder(i) for i in l))
 
     def to_json(self) -> UnfoldResult[FrozenDict[str, JsonValue]]:
-        if isinstance(self.value, FrozenDict):
-            return Result.success(self.value)
-        return Result.failure(
+        factory: ResultFactory[
+            FrozenDict[str, JsonValue], InvalidType
+        ] = ResultFactory()
+        fail = factory.failure(
             invalid_type.new(
                 "to_json", "FrozenDict[str, JsonValue]", self.value
             )
         )
+        return self.jval.map(
+            lambda _: fail,
+            lambda _: fail,
+            factory.success,
+        )
 
     def to_unfolder_dict(self) -> UnfoldResult[FrozenDict[str, Unfolder]]:
         return (
@@ -160,10 +177,9 @@ class Unfolder:
         )
 
 
-def to_raw(jval: JsonValue) -> Union[Dict[str, Any], List[Any], Primitive]:  # type: ignore[misc]
-    value = jval.unfold()
-    if isinstance(value, tuple):
-        return [to_raw(item) for item in value]  # type: ignore[misc]
-    if isinstance(value, FrozenDict):
-        return {key: to_raw(val) for key, val in value.items()}  # type: ignore[misc]
-    return value
+def to_raw(value: JsonValue) -> Union[Dict[str, Any], List[Any], Primitive]:  # type: ignore[misc]
+    return value.map(
+        lambda x: x,
+        lambda items: [to_raw(i) for i in items],  # type: ignore[misc]
+        lambda dict_obj: {key: to_raw(val) for key, val in dict_obj.items()},  # type: ignore[misc]
+    )
