@@ -32,11 +32,11 @@ def chain(
 
 
 def consume(p_iter: PureIter[Cmd[None]]) -> Cmd[None]:
-    def _action(act: CmdUnwrapper) -> None:
+    def _action(unwrapper: CmdUnwrapper) -> None:
         for c in p_iter:
-            act.unwrap(c)
+            unwrapper.act(c)
 
-    return new_cmd(_action)
+    return Cmd.new_cmd(_action)
 
 
 def filter_opt(items: PureIter[Optional[_T]]) -> PureIter[_T]:
